<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'greatnews_pro_blog_section', array(
	'title'             => esc_html__( 'Related Post/Blog','greatnews-pro' ),
	'description'       => esc_html__( 'Blog Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
	) );

// Blog content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_blog_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
	) ) );

// blog title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_blog_section',
	'active_callback' 	=> 'greatnews_pro_is_blog_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[blog_title]', array(
		'selector'            => '#related-posts div.section-header h2.section-title',
		'settings'            => 'greatnews_pro_theme_options[blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_blog_title_partial',
		) );
}

if ( $options['home_layout'] == 'sixth-design' || $options['home_layout'] == 'eight-design' || $options['home_layout'] == 'ninth-design' || $options['home_layout'] == 'eleven-design' || $options['home_layout'] == 'twelve-design' ):

// blog title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[blog_description]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_description'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[blog_description]', array(
	'label'           	=> esc_html__( 'Description', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_blog_section',
	'active_callback' 	=> 'greatnews_pro_is_blog_section_enable',
	'type'				=> 'textarea',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[blog_description]', array(
		'selector'            => '#business-latest-posts p.business-section-subtitle',
		'settings'            => 'greatnews_pro_theme_options[blog_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_blog_description_partial',
		) );
}

endif;

// Event social icons number control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[blog_count]', array(
	'default'          	=> $options['blog_count'],
	'sanitize_callback' => 'greatnews_pro_sanitize_number_range',
	'validate_callback' => 'greatnews_pro_validate_blog_count',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[blog_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'greatnews-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_blog_section',
	'active_callback'   => 'greatnews_pro_is_blog_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
	) );

if( $options['home_layout'] !== 'seventh-design' ):
// Blog column layout control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[blog_post_column]', array(
	'default'          	=> $options['blog_post_column'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[blog_post_column]', array(
	'label'             => esc_html__( 'Column Layout', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_blog_section_enable',
	'choices'			=> array( 
		'col-3'		=> esc_html__( 'Three Column', 'greatnews-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'greatnews-pro' ),
		),
	) );
endif;

// Blog content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_blog_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'greatnews-pro' ),
		'post' 		=> esc_html__( 'Post', 'greatnews-pro' ),
		'category' 	=> esc_html__( 'Category', 'greatnews-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'greatnews-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :
	// blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'greatnews_pro_theme_options[blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'greatnews_pro_sanitize_page',
		) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[blog_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'greatnews-pro' ), $i ),
	'section'           => 'greatnews_pro_blog_section',
	'choices'			=> greatnews_pro_page_choices(),
	'active_callback'	=> 'greatnews_pro_is_blog_section_content_page_enable',
	) ) );

	// blog posts drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[blog_content_post_' . $i . ']', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
	) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[blog_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'greatnews-pro' ), $i ),
	'section'           => 'greatnews_pro_blog_section',
	'choices'			=> greatnews_pro_post_choices(),
	'active_callback'	=> 'greatnews_pro_is_blog_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'greatnews_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'greatnews-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'greatnews_pro_is_blog_section_content_category_enable'
	) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'greatnews_pro_theme_options[blog_category_exclude]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_category_list',
	) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Category_Control( $wp_customize,'greatnews_pro_theme_options[blog_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'greatnews-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press CTRL key select multilple categories.', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'greatnews_pro_is_blog_section_content_recent_enable'
	) ) );

if ( $options['home_layout'] == 'sixth-design' || $options['home_layout'] == 'seventh-design' || $options['home_layout'] == 'eight-design' || $options['home_layout'] == 'ninth-design' || $options['home_layout'] == 'ninth-design' || $options['home_layout'] == 'eleven-design' ):

// blog title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[blog_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_button'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[blog_button]', array(
	'label'           	=> esc_html__( 'Button Label', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_blog_section',
	'active_callback' 	=> 'greatnews_pro_is_blog_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[blog_button]', array(
		'selector'            => '#business-latest-posts span.more-link a',
		'settings'            => 'greatnews_pro_theme_options[blog_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_blog_button_partial',
		) );
}

endif;

$wp_customize->add_setting( 'greatnews_pro_theme_options[ads_image_2]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_image'
	) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'greatnews_pro_theme_options[ads_image_2]',
	array(
		'label'       		=> esc_html__( 'Ads Image', 'greatnews-pro' ),
		'section'     		=> 'greatnews_pro_blog_section',
		) ) );

// ads link setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[ads_url_2]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[ads_url_2]', array(
	'label'           	=> esc_html__( 'Ads Url', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_blog_section',
	'type'				=> 'url',
	) );