<?php
/**
 * Course Section options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add Course section
$wp_customize->add_section( 'greatnews_pro_course_section', array(
	'title'             => esc_html__( 'Course','greatnews-pro' ),
	'description'       => esc_html__( 'Course Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
	) );

// Course content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[course_section_enable]', array(
	'default'			=> 	$options['course_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[course_section_enable]', array(
	'label'             => esc_html__( 'Course Section Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_course_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
	) ) );

// course title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[course_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[course_title]', array(
	'label'           	=> esc_html__( 'Course Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_course_section',
	'active_callback' 	=> 'greatnews_pro_is_course_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[course_title]', array(
		'selector'            => '#courses-section h2.business-section-title',
		'settings'            => 'greatnews_pro_theme_options[course_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_course_title_partial',
		) );
}


// course subtitle setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[course_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[course_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_course_section',
	'active_callback' 	=> 'greatnews_pro_is_course_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[course_subtitle]', array(
		'selector'            => '#courses-section p.business-section-subtitle',
		'settings'            => 'greatnews_pro_theme_options[course_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_course_subtitle_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[course_count]', array(
	'default'          	=> $options['course_count'],
	'sanitize_callback' => 'greatnews_pro_sanitize_number_range',
	'validate_callback' => 'greatnews_pro_validate_course_count',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[course_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'greatnews-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_course_section',
	'active_callback'   => 'greatnews_pro_is_course_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
	) );

// Course content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[course_content_type]', array(
	'default'          	=> $options['course_content_type'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[course_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_course_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_course_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'greatnews-pro' ),
		'post' 		=> esc_html__( 'Post', 'greatnews-pro' ),
		'category' 	=> esc_html__( 'Category', 'greatnews-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['course_count']; $i++ ) :
	// course pages drop down chooser control and setting
	$wp_customize->add_setting( 'greatnews_pro_theme_options[course_content_page_' . $i . ']', array(
		'sanitize_callback' => 'greatnews_pro_sanitize_page',
		) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[course_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'greatnews-pro' ), $i ),
	'section'           => 'greatnews_pro_course_section',
	'choices'			=> greatnews_pro_page_choices(),
	'active_callback'	=> 'greatnews_pro_is_course_section_content_page_enable',
	) ) );

	// course posts drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[course_content_post_' . $i . ']', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
	) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[course_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'greatnews-pro' ), $i ),
	'section'           => 'greatnews_pro_course_section',
	'choices'			=> greatnews_pro_post_choices(),
	'active_callback'	=> 'greatnews_pro_is_course_section_content_post_enable',
	) ) );

if ( $options['home_layout'] == 'default-design' ):

	// designation setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[designation_' . $i . ']', array(
	'sanitize_callback' => 'sanitize_text_field',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[designation_' . $i . ']', array(
	'label'           	=> sprintf( esc_html__( 'Designation %d', 'greatnews-pro' ), $i ),
	'section'        	=> 'greatnews_pro_course_section',
	'active_callback' 	=> 'greatnews_pro_is_course_section_enable',
	'type'				=> 'text',
	) );

endif;

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[course_content_category]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'greatnews_pro_theme_options[course_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'greatnews-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_course_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'greatnews_pro_is_course_section_content_category_enable'
	) ) );