<?php
/**
 * Media News Section options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add Media News section
$wp_customize->add_section( 'greatnews_pro_media_news_section', array(
	'title'             => esc_html__( 'Media News','greatnews-pro' ),
	'description'       => esc_html__( 'Media News Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
	) );

// Media News content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[media_news_section_enable]', array(
	'default'			=> 	$options['media_news_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[media_news_section_enable]', array(
	'label'             => esc_html__( 'Media News Section Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_media_news_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
	) ) );

// media news title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[media_news_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['media_news_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'greatnews_pro_theme_options[media_news_title]', array(
	'label'           	=> esc_html__( 'Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_media_news_section',
	'active_callback' 	=> 'greatnews_pro_is_media_news_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[media_news_title]', array(
		'selector'            => '#media-news div.section-header h2.section-title',
		'settings'            => 'greatnews_pro_theme_options[media_news_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'greatnews_pro_media_news_title_partial',
		) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[media_news_content_category]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_category_list',
	) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Category_Control( $wp_customize,'greatnews_pro_theme_options[media_news_content_category]', array(
	'label'             => esc_html__( 'Select Categories', 'greatnews-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL and select multiple category. Latest five posts will be shown from each selected category', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_media_news_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'greatnews_pro_is_media_news_section_enable',
	) ) );
