<?php
/**
 * Popular Tours Section options
 *
 * @popular_tours Theme Palace
 * @subpopular_tours Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add Popular Tours section
$wp_customize->add_section( 'greatnews_pro_popular_tours_section', array(
    'title'             => esc_html__( 'Popular Tours','greatnews-pro' ),
    'description'       => esc_html__( 'Popular Tours Section options.', 'greatnews-pro' ),
    'panel'             => 'greatnews_pro_front_page_panel',
) );

// Popular Tours content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[popular_tours_section_enable]', array(
    'default'           =>  $options['popular_tours_section_enable'],
    'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[popular_tours_section_enable]', array(
    'label'             => esc_html__( 'Popular Tours Section Enable', 'greatnews-pro' ),
    'section'           => 'greatnews_pro_popular_tours_section',
    'on_off_label'      => greatnews_pro_switch_options(),
) ) );

// popular tour title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[popular_tours_title]', array(
    'default'           => $options['popular_tours_title'],
    'sanitize_callback' => 'sanitize_text_field',
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[popular_tours_title]', array(
    'label'             => esc_html__( 'Title', 'greatnews-pro' ),
    'section'           => 'greatnews_pro_popular_tours_section',
    'active_callback'   => 'greatnews_pro_is_popular_tours_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'greatnews_pro_theme_options[popular_tours_title]', array(
        'selector'            => '#travel-tours-section h2.business-section-title',
        'settings'            => 'greatnews_pro_theme_options[popular_tours_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'greatnews_pro_popular_tours_title_partial',
    ) );
}

// Popular Tours content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[popular_tours_content_type]', array(
    'default'           => $options['popular_tours_content_type'],
    'sanitize_callback' => 'greatnews_pro_sanitize_select',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[popular_tours_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'greatnews-pro' ),
    'section'           => 'greatnews_pro_popular_tours_section',
    'type'              => 'select',
    'active_callback'   => 'greatnews_pro_is_popular_tours_section_enable',
    'choices'           => greatnews_pro_popular_tours_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[popular_tours_count]', array(
    'default'           => $options['popular_tours_count'],
    'sanitize_callback' => 'greatnews_pro_sanitize_number_range',
    'validate_callback' => 'greatnews_pro_validate_popular_tours_count',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[popular_tours_count]', array(
    'label'             => esc_html__( 'Number of Posts', 'greatnews-pro' ),
    'description'       => esc_html__( 'Note: Min 3 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'greatnews-pro' ),
    'section'           => 'greatnews_pro_popular_tours_section',
    'active_callback'   => 'greatnews_pro_is_popular_tours_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 3,
        'max'   => 9,
        'style' => 'width: 100px;'
        ),
) );

for ( $i=1; $i <= $options['popular_tours_count']; $i++ ) { 
    // popular_tours pages drop down chooser control and setting
    $wp_customize->add_setting( 'greatnews_pro_theme_options[popular_tours_content_page_' . $i . ']', array(
        'sanitize_callback' => 'greatnews_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[popular_tours_content_page_' . $i . ']', array(
        'label'             => sprintf ( esc_html__( 'Select Page %d', 'greatnews-pro' ), $i ),
        'section'           => 'greatnews_pro_popular_tours_section',
        'choices'           => greatnews_pro_page_choices(),
        'active_callback'   => 'greatnews_pro_is_popular_tours_section_content_page_enable',
    ) ) );

    // popular_tours posts drop down chooser control and setting
    $wp_customize->add_setting( 'greatnews_pro_theme_options[popular_tours_content_post_' . $i . ']', array(
        'sanitize_callback' => 'greatnews_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[popular_tours_content_post_' . $i . ']', array(
        'label'             => sprintf ( esc_html__( 'Select posts %d', 'greatnews-pro' ), $i ),
        'section'           => 'greatnews_pro_popular_tours_section',
        'choices'           => greatnews_pro_post_choices(),
        'active_callback'   => 'greatnews_pro_is_popular_tours_section_content_post_enable',
    ) ) );

    // popular_tours trips drop down chooser control and setting
    $wp_customize->add_setting( 'greatnews_pro_theme_options[popular_tours_content_trip_' . $i . ']', array(
        'sanitize_callback' => 'greatnews_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[popular_tours_content_trip_' . $i . ']', array(
        'label'             => sprintf ( esc_html__( 'Select Trip %d', 'greatnews-pro' ), $i ),
        'section'           => 'greatnews_pro_popular_tours_section',
        'choices'           => greatnews_pro_trip_choices(),
        'active_callback'   => 'greatnews_pro_is_popular_tours_section_content_trip_enable',
    ) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[popular_tours_content_category]', array(
    'sanitize_callback' => 'greatnews_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'greatnews_pro_theme_options[popular_tours_content_category]', array(
    'label'             => esc_html__( 'Select Category', 'greatnews-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'greatnews-pro' ),
    'section'           => 'greatnews_pro_popular_tours_section',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'greatnews_pro_is_popular_tours_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[popular_tours_content_trip_types]', array(
    'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'greatnews_pro_theme_options[popular_tours_content_trip_types]', array(
    'label'             => esc_html__( 'Select Trip Types', 'greatnews-pro' ),
    'section'           => 'greatnews_pro_popular_tours_section',
    'taxonomy'          => 'itinerary_types',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'greatnews_pro_is_popular_tours_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[popular_tours_content_activity]', array(
    'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'greatnews_pro_theme_options[popular_tours_content_activity]', array(
    'label'             => esc_html__( 'Select Activities', 'greatnews-pro' ),
    'section'           => 'greatnews_pro_popular_tours_section',
    'taxonomy'          => 'activity',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'greatnews_pro_is_popular_tours_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'greatnews_pro_theme_options[popular_tours_content_tours]', array(
    'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'greatnews_pro_theme_options[popular_tours_content_tours]', array(
    'label'             => esc_html__( 'Select Tourss', 'greatnews-pro' ),
    'section'           => 'greatnews_pro_popular_tours_section',
    'taxonomy'          => 'travel_locations',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'greatnews_pro_is_popular_tours_section_content_tours_enable'
) ) );
