<?php
/**
 * Video Section options
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */

// Add Video section
$wp_customize->add_section( 'greatnews_pro_video_section', array(
	'title'             => esc_html__( 'Video','greatnews-pro' ),
	'description'       => esc_html__( 'Video Section options.', 'greatnews-pro' ),
	'panel'             => 'greatnews_pro_front_page_panel',
) );

// Video content enable control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[video_section_enable]', array(
	'default'			=> 	$options['video_section_enable'],
	'sanitize_callback' => 'greatnews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Greatnews_Pro_Switch_Control( $wp_customize, 'greatnews_pro_theme_options[video_section_enable]', array(
	'label'             => esc_html__( 'Video Section Enable', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_video_section',
	'on_off_label' 		=> greatnews_pro_switch_options(),
) ) );

// video number control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[video_image]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'greatnews_pro_theme_options[video_image]', array(
	'label'             => esc_html__( 'Background Image', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_video_section',
	'active_callback'   => 'greatnews_pro_is_video_section_enable',
) ) );

// Video content type control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[video_content_type]', array(
	'default'          	=> $options['video_content_type'],
	'sanitize_callback' => 'greatnews_pro_sanitize_select',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[video_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_video_section',
	'type'				=> 'select',
	'active_callback' 	=> 'greatnews_pro_is_video_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'greatnews-pro' ),
		'post' 		=> esc_html__( 'Post', 'greatnews-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'greatnews-pro' ),
	),
) );

// video pages drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[video_content_page]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[video_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_video_section',
	'choices'			=> greatnews_pro_page_choices(),
	'active_callback'	=> 'greatnews_pro_is_video_section_content_page_enable',
) ) );

// video posts drop down chooser control and setting
$wp_customize->add_setting( 'greatnews_pro_theme_options[video_content_post]', array(
	'sanitize_callback' => 'greatnews_pro_sanitize_page',
) );

$wp_customize->add_control( new Greatnews_Pro_Dropdown_Chooser( $wp_customize, 'greatnews_pro_theme_options[video_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'greatnews-pro' ),
	'section'           => 'greatnews_pro_video_section',
	'choices'			=> greatnews_pro_post_choices(),
	'active_callback'	=> 'greatnews_pro_is_video_section_content_post_enable',
) ) );

// video title setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[video_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['video_title'],
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[video_title]', array(
	'label'           	=> esc_html__( 'Title', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_video_section',
	'active_callback' 	=> 'greatnews_pro_is_video_section_content_custom_enable',
	'type'				=> 'text',
) );

// video description setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[video_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['video_description'],
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[video_description]', array(
	'label'           	=> esc_html__( 'Description', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_video_section',
	'active_callback' 	=> 'greatnews_pro_is_video_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// video btn link setting and control
$wp_customize->add_setting( 'greatnews_pro_theme_options[video_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'greatnews_pro_theme_options[video_link]', array(
	'label'           	=> esc_html__( 'Video Link', 'greatnews-pro' ),
	'section'        	=> 'greatnews_pro_video_section',
	'active_callback' 	=> 'greatnews_pro_is_video_section_enable',
	'type'				=> 'url',
) );