<?php
/**
 * Most View section
 *
 * This is the template for the content of most_view section
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */
if ( ! function_exists( 'greatnews_pro_add_most_viewed_section' ) ) :
    /**
    * Add most_view section
    *
    *@since Greatnews Pro 1.0.0
    */
    function greatnews_pro_add_most_viewed_section() {
    	$options = greatnews_pro_get_theme_options();
        // Check if most_view is enabled on frontpage
        $most_viewed_enable = apply_filters( 'greatnews_pro_section_status', true, 'most_viewed_section_enable' );

        if ( true !== $most_viewed_enable ) {
            return false;
        }
        // Get most_view section details
        $section_details = array();
        $section_details = apply_filters( 'greatnews_pro_filter_most_viewed_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render most_view section now.
        greatnews_pro_render_most_viewed_section( $section_details );
    }
endif;

if ( ! function_exists( 'greatnews_pro_get_most_viewed_section_details' ) ) :
    /**
    * most_view section details.
    *
    * @since Greatnews Pro 1.0.0
    * @param array $input most_view section details.
    */
    function greatnews_pro_get_most_viewed_section_details( $input ) {
        $options = greatnews_pro_get_theme_options();

        // Content type.
        $most_viewed_content_type  = $options['most_viewed_content_type'];
        $most_viewed_count = ! empty( $options['most_viewed_count'] ) ? $options['most_viewed_count'] : 3;
        
        $content = array();
        switch ( $most_viewed_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $most_viewed_count; $i++ ) {
                    if ( ! empty( $options['most_viewed_content_page_' . $i] ) )
                        $page_ids[] = $options['most_viewed_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $most_viewed_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $most_viewed_count; $i++ ) {
                    if ( ! empty( $options['most_viewed_content_post_' . $i] ) )
                        $post_ids[] = $options['most_viewed_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $most_viewed_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['most_viewed_content_category'] ) ? $options['most_viewed_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $most_viewed_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['most_viewed_category_exclude'] ) ? $options['most_viewed_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $most_viewed_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['auth_id']   = get_the_author_meta('ID');
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = greatnews_pro_trim_content( 25 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// most_view section content details.
add_filter( 'greatnews_pro_filter_most_viewed_section_details', 'greatnews_pro_get_most_viewed_section_details' );


if ( ! function_exists( 'greatnews_pro_render_most_viewed_section' ) ) :
  /**
   * Start most_view section
   *
   * @return string most_view content
   * @since Greatnews Pro 1.0.0
   *
   */
function greatnews_pro_render_most_viewed_section( $content_details = array() ) {
    $options = greatnews_pro_get_theme_options();
    $most_viewed_content_type  = $options['most_viewed_content_type'];

    if ( empty( $content_details ) ) {
        return;
    } ?>

    <?php if ( $options['home_layout'] == 'seventh-design' ) { ?>

    <div id="blog-popular-posts" class="relative page-section">
        <div class="wrapper">

            <?php if ( ! empty( $options['most_viewed_title'] ) ) : ?>

                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['most_viewed_title'] ); ?></h2>
                </div><!-- .section-header -->

            <?php endif; ?>

            <div class="section-content">

                <?php foreach ( $content_details as $content ) : ?>

                    <article>
                        <div class="popular-post-item">
                            <div class="blog-featured-image">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>"></a>
                            </div><!-- .blog-featured-image -->

                            <div class="entry-container">
                                <?php if ( 'page' !== $most_viewed_content_type ) : ?>
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>                       
                                    </span><!-- .cat-links -->
                                <?php endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <span class="posted-on">
                                    <?php greatnews_pro_posted_on( $content['id'] ); ?>
                                </span><!-- .posted-on -->

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div>

                                <?php if( !empty( $options['most_viewed_button'] ) ): ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['most_viewed_button'] ); ?></a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </div><!-- .popular-post-item -->
                    </article>

                <?php endforeach; ?>

            </div><!-- .blog-section-content -->
        </div><!-- .wrapper -->
    </div>

    <?php 
}
} 
endif;