<?php
/**
 * Product section
 *
 * This is the template for the content of product section
 *
 * @package Theme Palace
 * @subpackage Greatnews Pro
 * @since Greatnews Pro 1.0.0
 */
if ( ! function_exists( 'greatnews_pro_add_product_section' ) ) :
    /**
    * Add product section
    *
    *@since Greatnews Pro 1.0.0
    */
    function greatnews_pro_add_product_section() {
    	$options = greatnews_pro_get_theme_options();
        // Check if product is enabled on frontpage
        $product_enable = apply_filters( 'greatnews_pro_section_status', true, 'product_section_enable' );

        if ( true !== $product_enable ) {
            return false;
        }
        // Get product section details
        $section_details = array();
        $section_details = apply_filters( 'greatnews_pro_filter_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render product section now.
        greatnews_pro_render_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'greatnews_pro_get_product_section_details' ) ) :
    /**
    * product section details.
    *
    * @since Greatnews Pro 1.0.0
    * @param array $input product section details.
    */
    function greatnews_pro_get_product_section_details( $input ) {
        $options = greatnews_pro_get_theme_options();

        // Content type.
        $product_content_type  = $options['product_content_type'];     
        $product_count = ! empty( $options['product_count'] ) ? $options['product_count'] : 4;
        
        
        $content = array();
        $content = array();
        switch ( $product_content_type ) {


            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $product_count; $i++ ) {
                    if ( ! empty( $options['product_content_product_' . $i] ) )
                        $page_ids[] = $options['product_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $product_count ),
                    'orderby'           => 'post__in',
                    );
            break;
            
            case 'product-category':
                $cat_id = ! empty( $options['product_content_product_category'] ) ? $options['product_content_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = greatnews_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// product section content details.
add_filter( 'greatnews_pro_filter_product_section_details', 'greatnews_pro_get_product_section_details' );


if ( ! function_exists( 'greatnews_pro_render_product_section' ) ) :
  /**
   * Start product section
   *
   * @return string product content
   * @since Greatnews Pro 1.0.0
   *
   */
   function greatnews_pro_render_product_section( $content_details = array() ) {
        $options = greatnews_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
      
        <div id="recent-products" class="relative page-section no-padding-top">
            <div class="wrapper">
                <div class="section-header">
                <?php if( !empty( $options['product_title'] ) ): ?>
                    <h2 class="shop-section-title"><?php echo esc_html( $options['product_title'] ); ?></h2>
                <?php endif;

                    if( !empty( $options['product_subtitle'] ) ):
                 ?>
                    <p class="shop-subtitle"><?php echo esc_html( $options['product_subtitle'] ); ?></p>
                <?php endif; ?>
                </div><!-- .section-header -->

                <div class="section-content">
                    <ul class="products col-4">

                    <?php foreach ( $content_details as $content ): ?>

                        <li class="product featured-products">
                            <a href="<?php echo esc_url( $content['url'] ) ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">

                                <img src="<?php echo esc_url( $content['image'] ) ?>">
                                <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ) ?></h2>
                                <span class="price">
                                    <ins>
                                        <span class="woocommerce-Price-amount amount">
                                            <span class="woocommerce-Price-currencySymbol">
                                
                                             <?php 
                                            $product = new WC_Product( $content['id'] );
                                            echo $product->get_price_html();
                                            ?>
                                            </span>
                                        </span>
                                    </ins>
                                </span>
                            </a>
                        </li>

                        <?php endforeach; ?>

                    </ul><!-- .product-slider -->
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>

    <?php }
endif;