<?php
/**
* Slider section
*
* This is the template for the content of slider section
*
* @package Theme Palace
* @subpackage Greatnews Pro
* @since Greatnews Pro 1.0.0
*/

$options = greatnews_pro_get_theme_options();
if( $options['slider_section_enable'] !== false ):

// Content type.
    $slider_content_type  = $options['slider_content_type'];
$slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 3;

$content_details = array();
switch ( $slider_content_type ) {

    case 'page':
    $page_ids = array();

    for ( $i = 1; $i <= $slider_count; $i++ ) {
        if ( ! empty( $options['slider_content_page_' . $i] ) )
            $page_ids[] = $options['slider_content_page_' . $i];
    }

    $args = array(
        'post_type'         => 'page',
        'post__in'          => ( array ) $page_ids,
        'posts_per_page'    => absint( $slider_count ),
        'orderby'           => 'post__in',
        );                    
    break;

    case 'post':
    $post_ids = array();

    for ( $i = 1; $i <= $slider_count; $i++ ) {
        if ( ! empty( $options['slider_content_post_' . $i] ) )
            $post_ids[] = $options['slider_content_post_' . $i];
    }
    $args = array(
        'post_type'         => 'post',
        'post__in'          => ( array ) $post_ids,
        'posts_per_page'    => absint( $slider_count ),
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );                    
    break;

    case 'category':
    $cat_ids = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
    $args = array(
        'post_type'         => 'post',
        'posts_per_page'    => absint( $slider_count ),
        'cat'               => absint( $cat_ids ),
        'ignore_sticky_posts'   => true,
        );                    
    break;

    default:
    break;
}


// Run The Loop.
$query = new WP_Query( $args );
if ( $query->have_posts() ) : 
    while ( $query->have_posts() ) : $query->the_post();
$page_post['id']        = get_the_id();
$page_post['auth_id']   = get_the_author_meta('ID');
$page_post['author_image']      = get_avatar( get_the_author_meta('ID'), 72 );
$page_post['title']     = get_the_title();
$page_post['url']       = get_the_permalink();
$page_post['excerpt']   = greatnews_pro_trim_content( 25 );
$page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
array_push( $content_details, $page_post );
endwhile;
endif;
wp_reset_postdata();
?>

<div id="posts-slider" class="relative">
    <?php if ( ! empty( $options['slider_title'] ) ) : ?>
        <div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $options['slider_title'] ); ?></h2>
        </div><!-- .section-header -->
    <?php endif; ?>

    <div class="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": <?php echo $options['slider_auto_play'] ? 'true' : 'false'; ?>, "draggable": true, "fade": false }'>
        <?php $i=1; foreach ( $content_details as $content ) : ?>

        <article>
            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"></div>
            <div class="entry-container">
                <?php if($options['home_layout'] == 'default-design'){ ?>

                <header class="entry-header">
                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                </header>

                <div class="entry-content">
                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                </div>

                <div class="entry-meta">
                    <?php greatnews_pro_posted_on( $content['id'] ); 

                    if ( $slider_content_type !== 'page' ) : ?>
                    <span class="cat-links">
                        <?php the_category( '', '', $content['id'] ); ?>
                    </span><!-- .cat-links -->
                <?php endif; ?>
            </div><!-- .entry-meta -->
            <div class="author-wrapper">
                <div class="author-image">
                    <?php echo wp_kses_post( $content['author_image'] ); ?>
                </div><!-- .author-image -->
                <div class="author-details">
                    <h3><?php echo greatnews_pro_author( $content['auth_id'] ); ?></h3>
                    <?php if( !empty( $options['designation_' . $i] ) ): ?>
                    <span class="designation"><?php echo esc_html( $options['designation_' . $i] ); ?></span>
                <?php endif; ?>
                </div>
            </div><!-- .author-wrapper -->

            <?php }else{

                if ( $slider_content_type !== 'page' ) : ?>
                <span class="cat-links">
                    <?php the_category( '', '', $content['id'] ); ?>
                </span><!-- .cat-links -->
            <?php endif; ?>

            <header class="entry-header">
                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
            </header>

            <div class="entry-content">
                <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
            </div>

            <div class="entry-meta">
                <?php greatnews_pro_posted_on( $content['id'] ); ?>
            </div><!-- .entry-meta -->
            <div class="author-wrapper">
                <div class="author-image">
                    <?php echo wp_kses_post( $content['author_image'] ); ?>
                </div><!-- .author-image -->
                <div class="author-details">
                    <h3><?php echo greatnews_pro_author( $content['auth_id'] ); ?></h3>
                    <span class="designation"><?php echo esc_html( $options['designation_' . $i] ); ?></span>
                </div>
            </div><!-- .author-wrapper -->
            <?php } ?>
        </div><!-- .entry-container -->
    </article>

    <?php $i++; endforeach; ?>

</div><!-- .featured-slider -->
</div><!-- #posts-slider -->

<?php endif; ?>
